## Changelog

### 0.1.2

* Fixed incorrect return value format of `search_meme()` URL field

### 0.1.1

* Made similarity threshold check case-insensitive

### 0.1.0

* Updated to fix apparent changes from KYM that broke the old library
* Modernized package metadata
* Made a few miscellaneous tweaks
